#!/bin/bash
#
# source: http://upower.freedesktop.org/releases/upower-0.9.16.tar.xz
#
# maintainer: gmg (monpontet.gerard@neuf.fr)
#

#------------------Set Some Variables

soft="upower"
softversion="0.9.16"
arch="i486"
cpu="i686"
packageversion="72.1"

buildir=$(pwd)
srcpkg="$buildir/$soft-$softversion.tar.xz"
src="$buildir/$soft-$softversion"
package="$soft-$softversion-$arch-$packageversion"
dest="$buildir/$package"

# -----------------Extract sources and get ready to build

cd $buildir
rm -rf $src
tar -xvf $srcpkg
rm -f $dest.txz
rm -rf $dest

#------------------Set correct permissions

cd $src
chown -R root:root .
find . \
 \( -perm 777 -o -perm 775 -o -perm 711 -o -perm 555 -o -perm 511 \) \
 -exec chmod 755 {} \; -o \
 \( -perm 666 -o -perm 664 -o -perm 600 -o -perm 444 -o -perm 440 -o -perm 400 \) \
 -exec chmod 644 {} \;
export CFLAGS="-O2 -march=$arch -mtune=$cpu"
export CXXFLAGS="-O2 -march=$arch -mtune=$cpu"
./configure \
  --prefix=/usr \
  --sysconfdir=/etc \
  --localstatedir=/var \
  --mandir=/usr/man \
  --disable-static \
  --without-idevice

make -j5
make install DESTDIR=$dest

find $dest | xargs file | grep -e "shared object" -e "executable" | grep ELF \
  | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

#------------------Don't clobber the config file on upgrades

mv $dest/etc/UPower/UPower.conf $dest/etc/UPower/UPower.conf.new

find $dest/usr/man -type f -exec gzip -9 {} \;

mkdir -p $dest/usr/doc/$soft-$softversion
cp -a \
  AUTHORS COPYING HACKING INSTALL NEWS README \
  $dest/usr/doc/$soft-$softversion

#-----------------Make the slack-desc files

mkdir -p $dest/install
cat << EODESC > $dest/install/slack-desc
# HOW TO EDIT THIS FILE:
# The "handy ruler" below makes it easier to edit a package description.  Line
# up the first '|' above the ':' following the base package name, and the '|'
# on the right side marks the last column you can put a character in.  You must
# make exactly 11 lines for the formatting to be correct.  It's also
# customary to leave one space after the ':'.

      |-----handy-ruler-------------------------------------------------------|
upower: upower - is an abstraction for enumerating power devices
upower:
upower: UPower is an abstraction for enumerating power devices, listening to
upower: device events and querying history and statistics. Any application or
upower: service on the system can access the org.freedesktop.UPower service
upower: via the system message bus. Some operations (such as suspending the 
upower: system) are restricted using PolicyKit.
upower:
upower:
upower:
upower:
EODESC

cat <<"DOINST"> $dest/install/doinst.sh
config() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  # If there's no config file by that name, mv it over:
  if [ ! -r $OLD ]; then
    mv $NEW $OLD
  elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
    # toss the redundant copy
    rm $NEW
  fi
  # Otherwise, we leave the .new copy for the admin to consider...
}

config etc/UPower/UPower.conf.new
DOINST

mkdir -p $dest/usr/src/$soft-$softversion
cp -a $buildir/build-$soft.sh $dest/usr/src/$soft-$softversion

#-------------------Make the packages and the md5sum

cd $dest
makepkg -l y -c n $dest.txz

cd $buildir
md5sum $package.txz > $package.md5